@@ -20,7 +20,6 @@
  * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/suncg3/cg3_driver.c,v 1.4 2001/05/16 06:48:10 keithp Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -29,7 +28,6 @@
 #define PSZ 8
 #include "xf86.h"
 #include "xf86_OSproc.h"
-#include "xf86Version.h"
 #include "mipointer.h"
 #include "mibstore.h"
 #include "micmap.h"
@@ -64,9 +62,9 @@ void CG3Sync(ScrnInfoPtr pScrn);
 #define CG3_VERSION 4000
 #define CG3_NAME "SUNCG3"
 #define CG3_DRIVER_NAME "suncg3"
-#define CG3_MAJOR_VERSION 1
-#define CG3_MINOR_VERSION 1
-#define CG3_PATCHLEVEL 0
+#define CG3_MAJOR_VERSION PACKAGE_VERSION_MAJOR
+#define CG3_MINOR_VERSION PACKAGE_VERSION_MINOR
+#define CG3_PATCHLEVEL PACKAGE_VERSION_PATCHLEVEL
 
 /* 
  * This contains the functions needed by the server after loading the driver
